import React from 'react';
import { BottomTabNavigationOptions, createBottomTabNavigator } from '@react-navigation/bottom-tabs';
import HomeScreen from './Home';
import BookScreen from './Book';
import LearnScreen from './Learn';
import SettingsScreen from './Settings';
import { useTranslation } from 'react-i18next';
import { StringConstants } from '../constants/string_constants';
import { AppColors } from '../constants/app_colors';
import { Image, StyleSheet } from 'react-native';
import Images from '../assets/images';

const Tab = createBottomTabNavigator();


const TabNavigator = () => {

  const screenOptions: BottomTabNavigationOptions = {
    tabBarActiveTintColor: AppColors.primary1,
    tabBarInactiveTintColor: AppColors.primary2,
  };

  const { t } = useTranslation();

  return (
    <Tab.Navigator
      screenOptions={screenOptions}>
      <Tab.Screen
        name="home"
        component={HomeScreen}
        options={{
          title: t(StringConstants.home),
          tabBarIcon: ({ focused }) => (
            <Image
              source={Images.home}
              tintColor={focused ? AppColors.primary1 : AppColors.primary2}
              style={styles.icon}
            />
          )
        }}
      />
      <Tab.Screen
        name="book"
        component={BookScreen}
        options={{
          title: t(StringConstants.book),
          tabBarIcon: ({ focused }) => (
            <Image
              source={Images.book}
              tintColor={focused ? AppColors.primary1 : AppColors.primary2}
              style={styles.icon}
            />
          )
        }}
      />
      <Tab.Screen
        name="learn"
        component={LearnScreen}
        options={{
          title: t(StringConstants.learn),
          tabBarIcon: ({ focused }) => (
            <Image
              source={Images.learn}
              tintColor={focused ? AppColors.primary1 : AppColors.primary2}
              style={styles.icon}
            />)
        }}
      />
      <Tab.Screen
        name="settings"
        component={SettingsScreen}
        options={{
          title: t(StringConstants.settings),
          tabBarIcon: ({ focused }) => (
            <Image
              source={Images.settings}
              tintColor={focused ? AppColors.primary1 : AppColors.primary2}
              style={styles.icon}
            />)
        }}
      />
    </Tab.Navigator>
  );
};


const styles = StyleSheet.create({
  icon: {
    height: 30,
    width: 30,
  },
});

export default TabNavigator;